@@ -1,4 +1,10 @@
 #!/usr/bin/env python
+
+from __future__ import absolute_import
+from __future__ import unicode_literals
+from __future__ import print_function
+from __future__ import division
+
 import pygraphviz as pgv
 
 A=pgv.AGraph()
@@ -13,4 +19,4 @@ A.add_edge(4,6)
 # make a subgraph with rank='same'
 B=A.add_subgraph([4,5,6],name='s1',rank='same')
 B.graph_attr['rank']='same'
-print A.string() # print dot file to standard output
+print(A.string()) # print dot file to standard output
