@@ -5,7 +5,7 @@ Do not add this file to the repository.
 
 """
 
-__version__ = '1.2'
+__version__ = '1.3.1'
 __revision__ = None
-__date__ = 'Sat Aug  3 09:57:44 2013'
+__date__ = 'Sun Sep  6 07:49:58 2015'
 
